@@ -2,13 +2,16 @@ import re
 from netaddr import IPNetwork
 from terraform_compliance.steps import resource_name
 from collections.abc import Iterable
-import json
 from copy import deepcopy
 import sys
 from terraform_compliance.common.exceptions import TerraformComplianceInternalFailure
 from semver import VersionInfo, compare
 from terraform_compliance.common.defaults import Defaults
 from radish.utils import console_write
+try:
+    import orjson as json
+except ImportError:
+    import json
 
 
 class EmptyStash(object):
@@ -371,7 +374,7 @@ def jsonify(string):
 
     try:
         return json.loads(string)
-    except json.decoder.JSONDecodeError:
+    except json.JSONDecodeError:
         return string
 
 
@@ -536,7 +539,7 @@ def merge_dicts(source, target):
     successor of dict_merge
     merges two dictionaries or lists into one
     overlapping list/dictionaries are also merged within each other
-   
+
     assume target is low priority
 
     conflicts
@@ -610,4 +613,4 @@ def remove_constant_values(target):
                 remove_constant_values(value)
     elif isinstance(target, list):
         for value in target:
-            remove_constant_values(value)
\ No newline at end of file
+            remove_constant_values(value)
